Changelog
=========

0.0.2 (2020-05-14)
-------------------

- Removed old organisation name from team name constraint.
- Added hard-delete functionality to soft-delete models.
- Fixed bug with soft-deleting groups of objects.

0.0.1 (2019-12-04)
-------------------

- Initial release
